@@ -1,4 +1,4 @@
-/* $Id: netload.h,v 1.23 2005/06/07 09:54:43 bdejean Exp $ */
+/* $Id: netload.h,v 1.25 2006/07/27 18:25:24 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -68,7 +68,8 @@ enum {
 	GLIBTOP_IF_FLAGS_LINK1,
 	GLIBTOP_IF_FLAGS_LINK2,
 	GLIBTOP_IF_FLAGS_ALTPHYS,
-	GLIBTOP_IF_FLAGS_MULTICAST
+	GLIBTOP_IF_FLAGS_MULTICAST,
+	GLIBTOP_IF_FLAGS_WIRELESS
 };
 
 enum GLIBTOP_IF_IN6_SCOPE
@@ -82,23 +83,23 @@ enum GLIBTOP_IF_IN6_SCOPE
 
 struct _glibtop_netload
 {
-	guint64	flags,
-		if_flags;		/* GLIBTOP_NETLOAD_IF_FLAGS	*/
+	guint64	flags;
+	guint64 if_flags;		/* GLIBTOP_NETLOAD_IF_FLAGS	*/
 
-	guint32	mtu,			/* GLIBTOP_NETLOAD_MTU		*/
-		subnet,			/* GLIBTOP_NETLOAD_SUBNET	*/
-		address;		/* GLIBTOP_NETLOAD_ADDRESS	*/
+	guint32	mtu;			/* GLIBTOP_NETLOAD_MTU		*/
+	guint32 subnet;			/* GLIBTOP_NETLOAD_SUBNET	*/
+	guint32 address;		/* GLIBTOP_NETLOAD_ADDRESS	*/
 
-	guint64	packets_in,		/* GLIBTOP_NETLOAD_PACKETS_IN	*/
-		packets_out,		/* GLIBTOP_NETLOAD_PACKETS_OUT	*/
-		packets_total,		/* GLIBTOP_NETLOAD_PACKETS_TOTAL*/
-		bytes_in,		/* GLIBTOP_NETLOAD_BYTES_IN	*/
-		bytes_out,		/* GLIBTOP_NETLOAD_BYTES_OUT	*/
-		bytes_total,		/* GLIBTOP_NETLOAD_BYTES_TOTAL	*/
-		errors_in,		/* GLIBTOP_NETLOAD_ERRORS_IN	*/
-		errors_out,		/* GLIBTOP_NETLOAD_ERRORS_OUT	*/
-		errors_total,		/* GLIBTOP_NETLOAD_ERRORS_TOTAL	*/
-		collisions;		/* GLIBTOP_NETLOAD_COLLISIONS	*/
+	guint64	packets_in;		/* GLIBTOP_NETLOAD_PACKETS_IN	*/
+	guint64 packets_out;		/* GLIBTOP_NETLOAD_PACKETS_OUT	*/
+	guint64 packets_total;		/* GLIBTOP_NETLOAD_PACKETS_TOTAL*/
+	guint64 bytes_in;		/* GLIBTOP_NETLOAD_BYTES_IN	*/
+	guint64 bytes_out;		/* GLIBTOP_NETLOAD_BYTES_OUT	*/
+	guint64 bytes_total;		/* GLIBTOP_NETLOAD_BYTES_TOTAL	*/
+	guint64 errors_in;		/* GLIBTOP_NETLOAD_ERRORS_IN	*/
+	guint64 errors_out;		/* GLIBTOP_NETLOAD_ERRORS_OUT	*/
+	guint64 errors_total;		/* GLIBTOP_NETLOAD_ERRORS_TOTAL	*/
+	guint64 collisions;		/* GLIBTOP_NETLOAD_COLLISIONS	*/
 
 	guint8 address6[16];		/* GLIBTOP_NETLOAD_ADDRESS6     */
 	guint8 prefix6[16];		/* GLIBTOP_NETLOAD_PREXIF6      */
