@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.34 2004/07/18 20:33:56 bdejean Exp $ */
+/* $Id: main.c,v 1.37 2005/12/12 09:38:08 jamesh Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include "daemon.h"
 
 #ifdef LIBGTOP_ENABLE_DEBUG
@@ -62,13 +63,13 @@ handle_parent_connection (int s)
     while (do_read (s, cmnd, sizeof (glibtop_command))) {
 	if (enable_debug)
 	    syslog_message (LOG_DEBUG,
-			    "Parent (%d) received command %d from client.",
-			    getpid (), (int) cmnd->command);
+			    "Parent (%d) received command %llu from client.",
+			    getpid (), cmnd->command);
 
 	if (cmnd->data_size >= BUFSIZ) {
 	    syslog_message (LOG_WARNING,
-			    "Client sent %d bytes, but buffer is %d",
-			    cmnd->data_size, BUFSIZ);
+			    "Client sent %llu bytes, but buffer is %lu",
+			    cmnd->data_size, (unsigned long)BUFSIZ);
 	    return;
 	}
 
@@ -78,8 +79,8 @@ handle_parent_connection (int s)
 
 	if (cmnd->data_size) {
 	    if (enable_debug)
-		syslog_message (LOG_DEBUG, "Client has %d bytes of data.",
-				(int) cmnd->data_size);
+		syslog_message (LOG_DEBUG, "Client has %llu bytes of data.",
+				cmnd->data_size);
 
 	    do_read (s, parameter, cmnd->data_size);
 
@@ -229,7 +230,7 @@ handle_parent_connection (int s)
 		       0, NULL);
 	    break;
 	default:
-	    syslog_message (LOG_ERR, "Parent received unknown command %u.",
+	    syslog_message (LOG_ERR, "Parent received unknown command %llu.",
 			    cmnd->command);
 	    break;
 	}
