@@ -1,4 +1,4 @@
-/* $Id: procstate.c,v 1.27 2004/08/03 11:40:37 bdejean Exp $ */
+/* $Id: procstate.c,v 1.29 2005/12/12 09:38:12 jamesh Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,10 +21,13 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/procstate.h>
 
+#include "glibtop_private.h"
+
 #include <sys/stat.h>
 
 static const unsigned long _glibtop_sysdeps_proc_state =
