@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: procsignal.c,v 1.16 2005/12/12 09:38:12 jamesh Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/procsignal.h>
@@ -35,46 +34,42 @@ static const unsigned long _glibtop_sysdeps_proc_signal =
 
 /* Init function. */
 
-int
+void
 glibtop_init_proc_signal_p (glibtop *server)
 {
-    server->sysdeps.proc_signal = _glibtop_sysdeps_proc_signal;
-
-    return 0;
+	server->sysdeps.proc_signal = _glibtop_sysdeps_proc_signal;
 }
 
 /* Provides detailed information about a process. */
 
-int
+void
 glibtop_get_proc_signal_p (glibtop *server, glibtop_proc_signal *buf,
 			   pid_t pid)
 {
-    struct tbl_procinfo procinfo;
-    int ret;
+	struct tbl_procinfo procinfo;
+	int ret;
 
-    glibtop_init_p (server, GLIBTOP_SYSDEPS_PROC_SIGNAL, 0);
-	
-    memset (buf, 0, sizeof (glibtop_proc_signal));
+	glibtop_init_p (server, GLIBTOP_SYSDEPS_PROC_SIGNAL, 0);
 
-    /* !!! THE FOLLOWING CODE RUNS SUID ROOT - CHANGE WITH CAUTION !!! */
+	memset (buf, 0, sizeof (glibtop_proc_signal));
 
-    glibtop_suid_enter (server);
-	
-    ret = table (TBL_PROCINFO, pid, (char *) &procinfo, 1,
-		 sizeof (struct tbl_procinfo)); 
+	/* !!! THE FOLLOWING CODE RUNS SUID ROOT - CHANGE WITH CAUTION !!! */
 
-    glibtop_suid_leave (server);
-		     
-    /* !!! END OF SUID ROOT PART !!! */
-	
-    if (ret != 1) return -1;
+	glibtop_suid_enter (server);
 
-    buf->signal [0] = procinfo.pi_sig;
-    buf->blocked [0] = procinfo.pi_sigmask;
-    buf->sigignore [0] = procinfo.pi_sigignore;
-    buf->sigcatch [0] = procinfo.pi_sigcatch;
+	ret = table (TBL_PROCINFO, pid, (char *) &procinfo, 1,
+		     sizeof (struct tbl_procinfo));
 
-    buf->flags = _glibtop_sysdeps_proc_signal;
+	glibtop_suid_leave (server);
 
-    return 0;
+	/* !!! END OF SUID ROOT PART !!! */
+
+	if (ret != 1) return;
+
+	buf->signal [0] = procinfo.pi_sig;
+	buf->blocked [0] = procinfo.pi_sigmask;
+	buf->sigignore [0] = procinfo.pi_sigignore;
+	buf->sigcatch [0] = procinfo.pi_sigcatch;
+
+	buf->flags = _glibtop_sysdeps_proc_signal;
 }
