@@ -1,4 +1,4 @@
-/* $Id: shm_limits.c,v 1.15 2005/12/12 09:38:13 jamesh Exp $ */
+/* $Id: shm_limits.c,v 1.16 2006/06/24 17:16:53 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -26,18 +26,23 @@
 #include <glibtop/shm_limits.h>
 
 #include <kvm.h>
+#include <rctl.h>
 #include <sys/shm.h>
 
-static const struct nlist nlst[] = { {"shminfo"}, {NULL} };
+static const struct nlist nlst[] = { {"glibtop_shm_limits"}, {NULL} };
 
-#if GLIBTOP_SOLARIS_RELEASE < 590
+#if GLIBTOP_SOLARIS_RELEASE >=51000
+static const unsigned long _glibtop_sysdeps_shm_limits = 0;
+#else
+# if GLIBTOP_SOLARIS_RELEASE < 50900
 static const unsigned long _glibtop_sysdeps_shm_limits =
 (1L << GLIBTOP_IPC_SHMMAX) + (1L << GLIBTOP_IPC_SHMMIN);
 
-#else
+# else
 static const unsigned long _glibtop_sysdeps_shm_limits =
 (1L << GLIBTOP_IPC_SHMMAX) + (1L << GLIBTOP_IPC_SHMMIN) +
 (1L << GLIBTOP_IPC_SHMMNI) + (1L << GLIBTOP_IPC_SHMSEG);
+# endif
 #endif
 
 /* Init function. */
@@ -45,12 +50,15 @@ static const unsigned long _glibtop_sysdeps_shm_limits =
 void
 glibtop_init_shm_limits_p (glibtop *server)
 {
+#if GLIBTOP_SOLARIS_RELEASE < 51000
+
 	kvm_t * const kd = server->machine.kd;
 
 	if(kd && !kvm_nlist(kd, nlst))
 		server->sysdeps.shm_limits = _glibtop_sysdeps_shm_limits;
 	else
 		server->sysdeps.shm_limits = 0;
+#endif
 }
 
 /* Provides information about sysv ipc limits. */
@@ -58,8 +66,11 @@ glibtop_init_shm_limits_p (glibtop *server)
 void
 glibtop_get_shm_limits_p (glibtop *server, glibtop_shm_limits *buf)
 {
+#if GLIBTOP_SOLARIS_RELEASE < 51000
+
 	kvm_t * const kd = server->machine.kd;
-	struct shminfo sinfo;
+        glibtop_shm_limits sinfo;
+
 
 	memset (buf, 0, sizeof (glibtop_shm_limits));
 
@@ -67,14 +78,32 @@ glibtop_get_shm_limits_p (glibtop *server, glibtop_shm_limits *buf)
 		return;
 
 	if(kvm_read(kd, nlst[0].n_value, (void *)&sinfo,
-		    sizeof(struct shminfo)) != sizeof(struct shminfo))
+                    sizeof(glibtop_shm_limits)) != sizeof(glibtop_shm_limits))
+
 		return;
 
 	buf->shmmax = sinfo.shmmax;
 	buf->shmmni = sinfo.shmmni;
-#if GLIBTOP_SOLARIS_RELEASE < 590
+#if GLIBTOP_SOLARIS_RELEASE < 50900
 	buf->shmmin = sinfo.shmmin;
 	buf->shmseg = sinfo.shmseg;
+# endif
+#endif
+#if GLIBTOP_SOLARIS_RELEASE >= 51000
+       rctlblk_t *rblk;
+       if ((rblk = malloc(rctlblk_size())) == NULL)
+               return;
+
+       if (getrctl("project.max-shm-memory", NULL, rblk, RCTL_FIRST) == -1)
+               return;
+       else
+              buf->shmmax = rctlblk_get_value(rblk);
+
+       if (getrctl("project.max-shm-ids", NULL, rblk, RCTL_FIRST) == -1)
+               return;
+       else
+               buf->shmmni = rctlblk_get_value(rblk);
+
 #endif
 	buf->flags = _glibtop_sysdeps_shm_limits;
 }
