@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: cpu.c,v 1.15 2005/12/12 09:38:14 jamesh Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/cpu.h>
 
@@ -30,20 +29,16 @@ static const unsigned long _glibtop_sysdeps_cpu = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_cpu_s (glibtop *server)
 {
-    server->sysdeps.cpu = _glibtop_sysdeps_cpu;
-
-    return 0;
+	server->sysdeps.cpu = _glibtop_sysdeps_cpu;
 }
 
 /* Provides information about cpu usage. */
 
-int
+void
 glibtop_get_cpu_s (glibtop *server, glibtop_cpu *buf)
 {
-    memset (buf, 0, sizeof (glibtop_cpu));
-
-    return 0;
+	memset (buf, 0, sizeof (glibtop_cpu));
 }
