@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: procstate.c,v 1.10 2005/12/12 09:38:15 jamesh Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/procstate.h>
@@ -33,23 +32,19 @@ static const unsigned long _glibtop_sysdeps_proc_state = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_proc_state_p (glibtop *server)
 {
-    server->sysdeps.proc_state = _glibtop_sysdeps_proc_state;
-
-    return 0;
+	server->sysdeps.proc_state = _glibtop_sysdeps_proc_state;
 }
 
 /* Provides detailed information about a process. */
 
-int
+void
 glibtop_get_proc_state_p (glibtop *server, glibtop_proc_state *buf,
 			  pid_t pid)
 {
-    glibtop_init_p (server, GLIBTOP_SYSDEPS_PROC_STATE, 0);
-	
-    memset (buf, 0, sizeof (glibtop_proc_state));
+	glibtop_init_p (server, GLIBTOP_SYSDEPS_PROC_STATE, 0);
 
-    return 0;
+	memset (buf, 0, sizeof (glibtop_proc_state));
 }
