@@ -1,4 +1,4 @@
-/* $Id: glibtop_machine.h,v 1.10 2003/10/19 16:55:56 carlos Exp $ */
+/* $Id: glibtop_machine.h,v 1.11 2003/10/20 15:20:16 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -48,7 +48,7 @@
 
 #include "loadavg.h"
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 /* Older versions of SunOS don't have a typedef for pid_t.
    Hopefully this will catch all those cases without causing other problems.
@@ -112,6 +112,6 @@ struct proc *_glibtop_find_pid (void *void_server, pid_t pid);
 
 #endif
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
